#
# spec file for package clinfo
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clinfo
Version:        3.0.23.01.25
Release:        1.5
Summary:        Utility that reports status information for all installed OpenCL ICDs
License:        SUSE-Public-Domain
Group:          Productivity/Other
URL:            https://github.com/Oblomov/clinfo/
Source:         https://github.com/Oblomov/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(OpenCL)

%description
A simple OpenCL application that enumerates all possible platform and
device properties. Inspired by AMD's program of the same name, it is
coded in pure C99 and it tries to output all possible information,
including that provided by platform-specific extensions, and not to
crash on platform-unsupported properties (e.g. 1.2 properties on 1.1
platforms).

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%make_build

%install
%make_install DESTDIR=%{buildroot} BINDIR=%{_bindir} MAN1DIR=%{_mandir}/man1

%files
%doc README.md
%license LICENSE
%{_bindir}/clinfo
%{_mandir}/man1/clinfo.1%{?ext_man}

%changelog
* Thu Jan 26 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.23.01.25
  * No upstream release notes.
* Thu Feb 25 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.21.02.21:
  * No upstream release notes.
* Thu Dec 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.20.11.20:
  * No upstream list of changes.
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2.2.18.04.06:
  * No upstream documentation of changes.
- Use %%%%license macro to package LICENSE file.
* Wed Oct 25 2017 mardnh@gmx.de
- Update to version 2.2.17.10.25
  * Warnings as errors
  * Correctly-rounded div and sqrt is only a flag for fp32
  * Fix CL_DEVICE_IMAGE_PITCH_ALIGNMENT unit to pixels.
  * fix manpage target
- Remove patch:
  * 0001-fix-manpage-target.patch (fixed upstream)
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 2.2.17.08.25
  * Version 2.2.17.08.25
  * Switch to annotated tags
  * Provide a `make install` target
  * Check for extra bits in some bitfields
  * Preliminary support for cl_khr_terminate_context
  * Declare support for OpenCL 2.x experimental
  * Actually add support for cl_khr_subgroup_named_barrier property
  * Add tentative missing defines for cl_khr_terminate_context
  * Defines for cl_khr_subgroup_named_barrier
- Add patch:
  * 0001-fix-manpage-target.patch
* Sat Jul 22 2017 mardnh@gmx.de
- Update to version 2.2.17.06.14
  * Version 2.2.17.06.14
  * OpenCL 2.2 support
  * Add "size" to "cache line" info
  * Add NMAKE makefile
  * Update Windows support
  * Avoid possible narrowing warnings
  * Use PRIuS to print size_t
  * Make UNUSED macro function-style
  * Also check default devices in clCreateContextFromType
* Fri Feb 17 2017 mpluskal@suse.com
- Update to version 2.1.17.02.09:
  * no upstream changelog provided
* Tue Jan 26 2016 mpluskal@suse.com
- Update to 2.1.16.01.12
  * no upstream changelog provided
* Wed Jan  6 2016 mardnh@gmx.de
- Update to version 2.1.16.01.06
  - Upstream does not provide a changelog
* Sat Nov 21 2015 mpluskal@suse.com
- Use optflags when building
- Tiny spec file cleanup with spec-cleaner
* Sat Jun 27 2015 mardnh@gmx.de
- Update to version 2.0.15.03.24
* Thu Jan 15 2015 mardnh@gmx.de
- initial packacke
